==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDockManagerResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerResourceStringsDescription } from "./WebDockManagerResourceStringsDescription";
/**
 * @hidden
 */
export let WebDockManagerResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerResourceStringsDescriptionMetadata.a == null) {
                WebDockManagerResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerResourceStringsDescriptionMetadata.c(WebDockManagerResourceStringsDescriptionMetadata.a);
            }
            if (a.j(WebDockManagerResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDockManagerResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerResourceStrings");
            a.item("Close", "String");
            a.item("Pin", "String");
            a.item("Unpin", "String");
            a.item("Maximize", "String");
            a.item("Minimize", "String");
            a.item("MoreOptions", "String");
            a.item("MoreTabs", "String");
            a.item("Panes", "String");
            a.item("Documents", "String");
        }
        static d(a) {
            WebDockManagerResourceStringsDescriptionMetadata.b(a);
            a.aa("WebDockManagerResourceStrings", () => new WebDockManagerResourceStringsDescription());
            a.z("WebDockManagerResourceStrings", WebDockManagerResourceStringsDescriptionMetadata.a);
        }
    }
    WebDockManagerResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerResourceStringsDescriptionMetadata, 'WebDockManagerResourceStringsDescriptionMetadata');
    WebDockManagerResourceStringsDescriptionMetadata.a = null;
    return WebDockManagerResourceStringsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebDockManagerResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerResourceStringsDescription } from "./WebDockManagerResourceStringsDescription";
/**
 * @hidden
 */
export let WebDockManagerResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDockManagerResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebDockManagerResourceStringsDescriptionMetadata.a == null) {
                WebDockManagerResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDockManagerResourceStringsDescriptionMetadata.c(WebDockManagerResourceStringsDescriptionMetadata.a);
            }
            if (a.k(WebDockManagerResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDockManagerResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DockManagerResourceStrings");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Close", "String");
            a.item("Pin", "String");
            a.item("Unpin", "String");
            a.item("Maximize", "String");
            a.item("Minimize", "String");
            a.item("MoreOptions", "String");
            a.item("MoreTabs", "String");
            a.item("Panes", "String");
            a.item("Documents", "String");
        }
        static d(a) {
            WebDockManagerResourceStringsDescriptionMetadata.b(a);
            a.ac("WebDockManagerResourceStrings", () => new WebDockManagerResourceStringsDescription());
            a.ab("WebDockManagerResourceStrings", WebDockManagerResourceStringsDescriptionMetadata.a);
        }
    }
    WebDockManagerResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDockManagerResourceStringsDescriptionMetadata, 'WebDockManagerResourceStringsDescriptionMetadata');
    WebDockManagerResourceStringsDescriptionMetadata.a = null;
    return WebDockManagerResourceStringsDescriptionMetadata;
})();
